Function capnp::serialize::read_message
[−]
[src]
pub fn read_message<R>(read: &mut R, options: ReaderOptions) -> Result<Reader<OwnedSegments>> where R: ReadReads a serialized message from a stream with the provided options.
For optimal performance, read should be a buffered reader type.